Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(11208)

Unified Diff: chrome/service/service_main.cc

Issue 2769023004: Cloud Print process type: service -> cloud-print-service (Closed)
Patch Set: . Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/common/service_process_util_unittest.cc ('k') | components/crash/content/app/breakpad_win.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/service/service_main.cc
diff --git a/chrome/service/service_main.cc b/chrome/service/service_main.cc
index 81ffb8874836ebf83524ef428448f87fd16771c6..248270603cfe95fd37ecc236d34a1771179e2b4f 100644
--- a/chrome/service/service_main.cc
+++ b/chrome/service/service_main.cc
@@ -12,8 +12,9 @@
#include "content/public/common/main_function_params.h"
#include "net/url_request/url_request.h"
-// Mainline routine for running as the service process.
-int ServiceProcessMain(const content::MainFunctionParams& parameters) {
+// Mainline routine for running as the Cloud Print service process.
+int CloudPrintServiceProcessMain(
+ const content::MainFunctionParams& parameters) {
// Chrome disallows cookies by default. All code paths that want to use
// cookies should go through the browser process.
net::URLRequest::SetDefaultCookiePolicyToBlock();
« no previous file with comments | « chrome/common/service_process_util_unittest.cc ('k') | components/crash/content/app/breakpad_win.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698